==> haskell-attoparsec-iso8601-1.0.0.0-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-attoparsec-iso8601.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: attoparsec-iso8601
version: 1.0.0.0
id: attoparsec-iso8601-1.0.0.0-JEUiOZBRw4G9zndWmmbYpY
key: attoparsec-iso8601-1.0.0.0-JEUiOZBRw4G9zndWmmbYpY
license: BSD3
copyright: (c) 2011-2016 Bryan O'\''Sullivan
           (c) 2011 MailRank, Inc.
maintainer: Adam Bergmark <adam@bergmark.nl>
stability: experimental
homepage: https://github.com/bos/aeson
synopsis: Parsing of ISO 8601 dates, originally from aeson.
description:
    Parsing of ISO 8601 dates, originally from aeson.
category: Parsing
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    Data.Attoparsec.Time.Internal Data.Attoparsec.Time
abi: 29cd4ed5a656a9d9a7eba92426c2d333
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/attoparsec-iso8601-1.0.0.0
library-dirs: /usr/lib/ghc-8.0.2/site-local/attoparsec-iso8601-1.0.0.0
dynamic-library-dirs: /usr/lib/x86_64-linux-ghc-8.0.2
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/attoparsec-iso8601-1.0.0.0
hs-libraries: HSattoparsec-iso8601-1.0.0.0-JEUiOZBRw4G9zndWmmbYpY
depends:
    attoparsec-0.13.1.0-DfCcdDKzvgP57nVHcPqiZF base-4.9.1.0
    base-compat-0.9.3-KeJp8zYMpcS9WibvTcxU22
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq time-1.6.0.1
haddock-interfaces: /usr/share/doc/haskell-attoparsec-iso8601/html/attoparsec-iso8601.haddock
haddock-html: /usr/share/doc/haskell-attoparsec-iso8601/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-attoparsec-iso8601-1.0.0.0-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-attoparsec-iso8601.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: attoparsec-iso8601
version: 1.0.0.0
id: attoparsec-iso8601-1.0.0.0-37ZPXvjpXEiAGjkWYbuWUH
key: attoparsec-iso8601-1.0.0.0-37ZPXvjpXEiAGjkWYbuWUH
license: BSD3
copyright: (c) 2011-2016 Bryan O'\''Sullivan
           (c) 2011 MailRank, Inc.
maintainer: Adam Bergmark <adam@bergmark.nl>
stability: experimental
homepage: https://github.com/bos/aeson
synopsis: Parsing of ISO 8601 dates, originally from aeson.
description:
    Parsing of ISO 8601 dates, originally from aeson.
category: Parsing
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    Data.Attoparsec.Time.Internal Data.Attoparsec.Time
abi: ae3029c21ea900707fc8dddaed76313b
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/attoparsec-iso8601-1.0.0.0
library-dirs: /usr/lib/ghc-8.0.2/site-local/attoparsec-iso8601-1.0.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/attoparsec-iso8601-1.0.0.0
hs-libraries: HSattoparsec-iso8601-1.0.0.0-37ZPXvjpXEiAGjkWYbuWUH
depends:
    attoparsec-0.13.1.0-DWdB5NAuEI54zL0UJYXwyo base-4.9.1.0
    base-compat-0.9.3-KeJp8zYMpcS9WibvTcxU22
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq time-1.6.0.1
haddock-interfaces: /usr/share/doc/haskell-attoparsec-iso8601/html/attoparsec-iso8601.haddock
haddock-html: /usr/share/doc/haskell-attoparsec-iso8601/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
